@@ -24,12 +24,12 @@ import (
 const standardIndentation = "    "
 
 // ToStandardJSON return a string with the JSON representation of the interface{}
-func ToStandardJSON(i interface{}) (string, error) {
+func ToStandardJSON(i any) (string, error) {
 	return ToJSON(i, "", standardIndentation)
 }
 
 // ToJSON return a string with the JSON representation of the interface{}
-func ToJSON(i interface{}, prefix string, indentation string) (string, error) {
+func ToJSON(i any, prefix string, indentation string) (string, error) {
 	buffer := &bytes.Buffer{}
 	encoder := json.NewEncoder(buffer)
 	encoder.SetEscapeHTML(false)
