@@ -41,7 +41,7 @@ func (s *composeService) useAPISocket(project *types.Project) (*types.Project, e
 		return project, nil
 	}
 
-	if s.dockerCli.ServerInfo().OSType == "windows" {
+	if s.getContextInfo().ServerOSType() == "windows" {
 		return nil, errors.New("use_api_socket can't be used with a Windows Docker Engine")
 	}
 
@@ -49,6 +49,7 @@ func (s *composeService) useAPISocket(project *types.Project) (*types.Project, e
 	if err != nil {
 		return nil, fmt.Errorf("resolving credentials failed: %w", err)
 	}
+
 	newConfig := &configfile.ConfigFile{
 		AuthConfigs: creds,
 	}
