@@ -32,20 +32,20 @@ import (
 	"github.com/compose-spec/compose-go/v2/loader"
 	"github.com/compose-spec/compose-go/v2/types"
 	"github.com/distribution/reference"
-	"github.com/docker/compose/v2/internal/oci"
-	"github.com/docker/compose/v2/pkg/api"
-	"github.com/docker/compose/v2/pkg/compose/transform"
-	"github.com/docker/compose/v2/pkg/progress"
 	"github.com/opencontainers/go-digest"
 	"github.com/opencontainers/image-spec/specs-go"
 	v1 "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
+
+	"github.com/docker/compose/v5/internal/oci"
+	"github.com/docker/compose/v5/pkg/api"
+	"github.com/docker/compose/v5/pkg/compose/transform"
 )
 
 func (s *composeService) Publish(ctx context.Context, project *types.Project, repository string, options api.PublishOptions) error {
-	return progress.RunWithTitle(ctx, func(ctx context.Context) error {
+	return Run(ctx, func(ctx context.Context) error {
 		return s.publish(ctx, project, repository, options)
-	}, s.stdinfo(), "Publishing")
+	}, "publish", s.events)
 }
 
 //nolint:gocyclo
@@ -71,11 +71,10 @@ func (s *composeService) publish(ctx context.Context, project *types.Project, re
 		return err
 	}
 
-	w := progress.ContextWriter(ctx)
-	w.Event(progress.Event{
+	s.events.On(api.Resource{
 		ID:     repository,
 		Text:   "publishing",
-		Status: progress.Working,
+		Status: api.Working,
 	})
 	if logrus.IsLevelEnabled(logrus.DebugLevel) {
 		logrus.Debug("publishing layers")
@@ -90,14 +89,19 @@ func (s *composeService) publish(ctx context.Context, project *types.Project, re
 			return err
 		}
 
-		resolver := oci.NewResolver(s.configFile())
+		var insecureRegistries []string
+		if options.InsecureRegistry {
+			insecureRegistries = append(insecureRegistries, reference.Domain(named))
+		}
+
+		resolver := oci.NewResolver(s.configFile(), insecureRegistries...)
 
 		descriptor, err := oci.PushManifest(ctx, resolver, named, layers, options.OCIVersion)
 		if err != nil {
-			w.Event(progress.Event{
+			s.events.On(api.Resource{
 				ID:     repository,
 				Text:   "publishing",
-				Status: progress.Error,
+				Status: api.Error,
 			})
 			return err
 		}
@@ -146,10 +150,10 @@ func (s *composeService) publish(ctx context.Context, project *types.Project, re
 			}
 		}
 	}
-	w.Event(progress.Event{
+	s.events.On(api.Resource{
 		ID:     repository,
 		Text:   "published",
-		Status: progress.Done,
+		Status: api.Done,
 	})
 	return nil
 }
@@ -239,6 +243,7 @@ func processFile(ctx context.Context, file string, project *types.Project, extFi
 		options.SkipExtends = true
 		options.SkipConsistencyCheck = true
 		options.ResolvePaths = true
+		options.SkipInclude = true
 		options.Profiles = project.Profiles
 	})
 	if err != nil {
@@ -293,14 +298,10 @@ func (s *composeService) generateImageDigestsOverride(ctx context.Context, proje
 	return override.MarshalYAML()
 }
 
-//nolint:gocyclo
 func (s *composeService) preChecks(project *types.Project, options api.PublishOptions) (bool, error) {
 	if ok, err := s.checkOnlyBuildSection(project); !ok || err != nil {
 		return false, err
 	}
-	if options.AssumeYes {
-		return true, nil
-	}
 	bindMounts := s.checkForBindMount(project)
 	if len(bindMounts) > 0 {
 		b := strings.Builder{}
@@ -339,65 +340,35 @@ func (s *composeService) preChecks(project *types.Project, options api.PublishOp
 			return false, err
 		}
 	}
-	envVariables, err := s.checkEnvironmentVariables(project, options)
+	err = s.checkEnvironmentVariables(project, options)
 	if err != nil {
 		return false, err
 	}
-	if len(envVariables) > 0 {
-		b := strings.Builder{}
-		b.WriteString("you are about to publish environment variables within your OCI artifact.\n" +
-			"please double check that you are not leaking sensitive data\n")
-		for key, val := range envVariables {
-			b.WriteString("Service/Config  ")
-			b.WriteString(key)
-			b.WriteRune('\n')
-			for k, v := range val {
-				b.WriteString(fmt.Sprintf("%s=%v\n", k, *v))
-			}
-		}
-		b.WriteString("Are you ok to publish these environment variables?")
-		confirm, err := s.prompt(b.String(), false)
-		if err != nil || !confirm {
-			return false, err
-		}
-	}
 	return true, nil
 }
 
-func (s *composeService) checkEnvironmentVariables(project *types.Project, options api.PublishOptions) (map[string]types.MappingWithEquals, error) {
-	envVarList := map[string]types.MappingWithEquals{}
+func (s *composeService) checkEnvironmentVariables(project *types.Project, options api.PublishOptions) error {
 	errorList := map[string][]string{}
 
 	for _, service := range project.Services {
 		if len(service.EnvFiles) > 0 {
 			errorList[service.Name] = append(errorList[service.Name], fmt.Sprintf("service %q has env_file declared.", service.Name))
 		}
-		if len(service.Environment) > 0 {
-			errorList[service.Name] = append(errorList[service.Name], fmt.Sprintf("service %q has environment variable(s) declared.", service.Name))
-			envVarList[service.Name] = service.Environment
-		}
-	}
-
-	for _, config := range project.Configs {
-		if config.Environment != "" {
-			errorList[config.Name] = append(errorList[config.Name], fmt.Sprintf("config %q is declare as an environment variable.", config.Name))
-			envVarList[config.Name] = types.NewMappingWithEquals([]string{fmt.Sprintf("%s=%s", config.Name, config.Environment)})
-		}
 	}
 
 	if !options.WithEnvironment && len(errorList) > 0 {
 		errorMsgSuffix := "To avoid leaking sensitive data, you must either explicitly allow the sending of environment variables by using the --with-env flag,\n" +
 			"or remove sensitive data from your Compose configuration"
-		errorMsg := ""
+		var errorMsg strings.Builder
 		for _, errors := range errorList {
 			for _, err := range errors {
-				errorMsg += fmt.Sprintf("%s\n", err)
+				errorMsg.WriteString(fmt.Sprintf("%s\n", err))
 			}
 		}
-		return nil, fmt.Errorf("%s%s", errorMsg, errorMsgSuffix)
+		return fmt.Errorf("%s%s", errorMsg.String(), errorMsgSuffix)
 
 	}
-	return envVarList, nil
+	return nil
 }
 
 func envFileLayers(files map[string]string) []v1.Descriptor {
@@ -422,11 +393,12 @@ func (s *composeService) checkOnlyBuildSection(project *types.Project) (bool, er
 		}
 	}
 	if len(errorList) > 0 {
-		errMsg := "your Compose stack cannot be published as it only contains a build section for service(s):\n"
+		var errMsg strings.Builder
+		errMsg.WriteString("your Compose stack cannot be published as it only contains a build section for service(s):\n")
 		for _, serviceInError := range errorList {
-			errMsg += fmt.Sprintf("- %q\n", serviceInError)
+			errMsg.WriteString(fmt.Sprintf("- %q\n", serviceInError))
 		}
-		return false, errors.New(errMsg)
+		return false, errors.New(errMsg.String())
 	}
 	return true, nil
 }
